[−][src]Struct cbor_data::DictBuilder
Builder for an dict value.
Calling the finish() method will return either the fully constructed
CBOR value (if this was the top-level dict) or the builder of the array or dict into
which this dict was placed.
If you want to recursively create a CBOR structure without statically known recursion limit
then you’ll want to take a look at the WriteToDict::write_dict_rec()
method (the compiler would otherwise kindly inform you of a type expansion hitting the recursion
limit while instantiating your recursive function).
Implementations
impl<'a, T: 'static> DictBuilder<'a, T>[src]
pub fn finish(self) -> T[src]
Finish building this dict and return to the outer context. In case of a
top-level dict this returns the complete Cbor value.
pub fn write_array(self, key: &str, tag: Option<u64>) -> ArrayBuilder<'a, Self>[src]
Write a nested array that is then filled by the returned builder.
You can resume building this outer dict by using the finish()
method.
pub fn write_dict(self, key: &str, tag: Option<u64>) -> DictBuilder<'a, Self>[src]
Write a nested dict that is then filled by the returned builder.
You can resume building this outer dict by using the finish()
method.