StringIter

Struct StringIter 

pub struct StringIter<'a>(/* private fields */);
Iterator yielding the fragments of a text string item

Parsing an item can in general not return a contiguous string due to indefinite-length encoding. This Iterator gives you the choice whether you want to inspect the fragments or build a contiguous string by allocating the necessary memory.

Implementations

Source

impl<'a> StringIter<'a>

pub fn is_indefinite(&self) -> bool

Indicates whether the underlying encoding was definite or indefinite

If you want to check whether the string is available as contiguous slice, see as_str, which will also work for 0- and 1-fragment strings using indefinite-length encoding.

pub fn is_empty(&self) -> bool

Returns true if the string consists of zero fragments

A return value of false does not indicate that the string contains characters!

pub fn as_str(&self) -> Option<&'a str>

Try to borrow the string as a single slice

This will only succeed for definite length encoding or strings with 0 or 1 fragments.

pub fn as_cow(&self) -> Cow<'a, str>

Extract the full string, borrowing if possible and allocating if necessary

pub fn len(&self) -> usize

compute the total length of all contained slices